Name: docbook-style-xsl
Version: 1.78.1
Release: 1%{?_dist_release}
Group: Applications/Text

Summary: Norman Walsh's XSL stylesheets for DocBook XML.
Summary(ja): DocBook XML用 XSLスタイルシート

License: Copyright only
URL: http://docbook.sourceforge.net/projects/xsl/

Source0: http://downloads.sourceforge.net/docbook/docbook-xsl-%{version}.tar.bz2
Source1: %{name}.Makefile
Source2: http://downloads.sourceforge.net/docbook/docbook-xsl-doc-%{version}.tar.bz2

# Avoid proportional-column-width for passivetex (bug #176766).
Patch1: docbook-xsl-pagesetup.patch
# Hard-code the margin-left work around to expect passivetex (bug #113456).
Patch2: docbook-xsl-marginleft.patch
# fix of #161619 - adjustColumnWidths now available
Patch3: docbook-xsl-newmethods.patch
# change a few non-constant expressions to constant - needed for passivetex(#366441)
Patch4: docbook-xsl-non-constant-expressions.patch
# added fixes for passivetex extension and list-item-body(#161371)
Patch5: docbook-xsl-list-item-body.patch
#workaround missing mandir section problem (#727251)
Patch6: docbook-xsl-mandir.patch


BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildArch: noarch

Provides: docbook-xsl = %{version}
Requires: docbook-dtd-xml
# xml-common was using /usr/share/xml until 0.6.3-8.
Requires: xml-common >= 0.6.3-8
# required because of usage of /usr/bin/xmlcatalog
Requires(post): libxml2 >= 2.4.8
Requires(postun): libxml2 >= 2.4.8
# PassiveTeX before 1.21 can't handle the newer stylesheets.
Conflicts: passivetex < 1.21

Vendor: Project Vine
Distribution: Vine Linux

%description
These XSL stylesheets allow you to transform any DocBook XML document to
other formats, such as HTML, FO, and XHMTL.  They are highly customizable.

%description -l ja
この XSL スタイルシートを使って, さまざまな DocBook XML 形式のドキュメント
を HTML や FO や XHTML などの他のフォーマットに変換することができます.


%prep
%setup -q -n docbook-xsl-%{version}
pushd ..
tar jxf %{SOURCE2}
popd
%patch1 -p1 -b .pagesetup
%patch2 -p1 -b .marginleft
%patch3 -p1 -b .newmethods
%patch4 -p1 -b .nonconstant
%patch5 -p1 -b .listitembody
%patch6 -p1 -b .mandir

cp %{SOURCE1} Makefile

# fix of non UTF-8 files rpmlint warnings
for fhtml in $(find ./doc -name '*.html' -type f)
do
  iconv -f ISO-8859-1 -t UTF-8 "$fhtml" -o "$fhtml".tmp
  mv -f "$fhtml".tmp "$fhtml"
  sed -i 's/charset=ISO-8859-1/charset=UTF-8/' "$fhtml"
done

for f in $(find -name "*'*")
do
  mv -v "$f" $(echo "$f" | tr -d "'")
done

%build

%install
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT

DESTDIR=$RPM_BUILD_ROOT
make install BINDIR=$DESTDIR%{_bindir} DESTDIR=$DESTDIR%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}
cp -a VERSION.xsl $DESTDIR%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}/VERSION.xsl
ln -s xsl-stylesheets-%{version} \
	$DESTDIR%{_datadir}/sgml/docbook/xsl-stylesheets

# Don't ship the extensions (bug #177256).
rm -rf $DESTDIR%{_datadir}/sgml/docbook/xsl-stylesheets/extensions/*

%clean
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT

%post
CATALOG=%{_sysconfdir}/xml/catalog
%{_bindir}/xmlcatalog --noout --add "rewriteSystem" \
 "http://docbook.sourceforge.net/release/xsl/%{version}" \
 "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteURI" \
 "http://docbook.sourceforge.net/release/xsl/%{version}" \
 "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteSystem" \
 "http://docbook.sourceforge.net/release/xsl/current" \
 "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteURI" \
 "http://docbook.sourceforge.net/release/xsl/current" \
 "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG

%postun
# remove entries only on removal of package
if [ "$1" = 0 ]; then
  CATALOG=%{_sysconfdir}/xml/catalog
  %{_bindir}/xmlcatalog --noout --del \
   "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
fi


%files
%defattr (-,root,root)
%doc BUGS README TODO doc
%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}
%{_datadir}/sgml/docbook/xsl-stylesheets


%changelog
* Sun Nov 16 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.78.1-1
- new upstream release
- update Patch2 from fedora

* Mon Dec 30 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.77.1-2
- new upstream release

* Sat Sep 29 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.77.1-1
- new upstream release
- add Patch6 (docbook-xsl-mandir.patch) from fedora
- update Source1 (%{name}.Makefile)
- update following patches from fedora
  - Patch1 (docbook-xsl-pagesetup.patch)
  - Patch2 (docbook-xsl-marginleft.patch)
  - Patch3 (docbook-xsl-newmethods.patch)
- update spec file based on fedora package
  * Tue Jun  5 2012 Ondrej Vasik <ovasik@redhat.com> 1.77.1-2
  - ship VERSION.xsl file (#829014)
  * Tue Jun  5 2012 Ondrej Vasik <ovasik@redhat.com> 1.77.1-1
  - new stable upstream release 1.77.1
  - defuzz patches
  * Tue Sep  6 2011 Ondrej Vasik <ovasik@redhat.com> 1.76.1-4
  - revert previous change, workaround the mandir links issue
    in buildroot (#727251)
  * Mon Aug 29 2011 Ondrej Vasik <ovasik@redhat.com> 1.76.1-3
  - make man.output.in.separate.dir "on" by default (#727251)
  * Tue Nov 02 2010 Ondrej Vasik <ovasik@redhat.com> 1.76.1-1
  - new upstream release 1.76.1
  * Mon Sep 06 2010 Ondrej Vasik <ovasik@redhat.com> 1.76.0-1
  - new upstream release 1.76.0

* Fri Apr 22 2011 IWAI, Masaharu <iwai@alib.jp> 1.76.1-1
- new upstream release
- add Vendor and Distribution tags

* Sun Mar  7 2010 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.75.3-6
- updated based on FC 1.75.3-5
  * Fri Dec 18 2009 Ondrej Vasik <ovasik@redhat.com> 1.75.3-5
  - comment patches purpose
  - License Copyright only
  * Mon May 11 2009 Ondrej Vasik <ovasik@redhat.com> 1.75.0-1
  - New upstream release 1.75.0
  - update marginleft patch
  * Mon Feb 23 2009 Ondrej Vasik <ovasik@redhat.com> 1.74.2-2
  - updated Makefile: do ship .svg images(#486849), xsl
    stylesheets for website, xhtml-1_1, docbook -> epub
    convertor
  * Wed Feb 11 2009 Ondrej Vasik <ovasik@redhat.com> 1.74.0-7
  - fix broken varlistentry (#479683)
  * Mon Feb 02 2009 Ondrej Vasik <ovasik@redhat.com> 1.74.0-6
  - fix improper localization for rtl languages, thanks
    Muayyad Alsadi(#475077)
  * Wed Jan 28 2009 Ondrej Vasik <ovasik@redhat.com> 1.74.0-5
  - fix xsl stylesheets for rtl languages(#475077)
  * Fri Dec 12 2008 Ondrej Vasik <ovasik@redhat.com> 1.74.0-4
  - Author_Group "<orgname>" merged between "<surname>"
    and "<surname>" (#473019)
  * Wed Aug 06 2008 Kamil Dudka <kdudka@redhat.com> 1.74.0-3
  - Rediffed all patches to work with patch --fuzz=0
  * Wed Aug 06 2008 Kamil Dudka <kdudka@redhat.com> 1.74.0-2
  - Tiny changes in docbook-xsl-newmethods.patch to work with xalan
    (#452867)
  * Fri Dec 14 2007 Ondrej Vasik <ovasik@redhat.com> 1.73.2-9
  - added fixes for passivetex extension and list-item-body
    (#161371)
  * Mon Dec 03 2007 Ondrej Vasik <ovasik@redhat.com> 1.73.2-6
  - fixed docbook-xsl-pagesetup.patch to follow Norman Walsh's
    documentation for nonpassivetex processing(#307001)
  * Tue Nov 27 2007 Ondrej Vasik <ovasik@redhat.com> 1.73.2-5
  - convert all html files in doc to UTF-8 in prep
    (latest rpmlint gives warnings)
  - no longer using release in style-xsl dir(#389231)

* Fri Aug 15 2008 Shu KONNO <owa@bg.wakwak.com> 1.73.2-5vl5
- applied new versioning policy, spec in utf-8

* Fri Jan 25 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.73.2-5vl1
- updated to 1.73.2 based on Fedora development
  * Tue Dec 11 2007 Ondrej Vasik <ovasik@redhat.com> 1.73.2-4
  - remove entries from xmlcatalog only on removal of package
    (required because of the last change with droping release
     -caused drop of catalog entries during update)
  * Wed Dec 05 2007 Ondrej Vasik <ovasik@redhat.com> 1.73.2-3
  - change a few non-constant expressions to constant that
    could now be handled by passivetex(#366441)
  - fixed docbook-xsl-pagesetup.patch to follow Norman Walsh's
    documentation for nonpassivetex processing(#307001)
    (use passivetex.extensions = 1 option in param.xsl for
     processing with passivetex)
  * Fri Sep  7 2007 Ondrej Vasik <ovasik@redhat.com> 1.73.2-2
  - Added PreReq of libxml2(#253962)

* Sun Jul 22 2007 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.72.0-3vl1
- updated to 1.72.0 based on Fedora development
  * Mon Jun 18 2007 Ondrej Vasik <ovasik@redhat.com> 1.72.0-3
  - patch fixing #161619 taken from upstream
  * Tue Jan 23 2007 Tim Waugh <twaugh@redhat.com> 1.72.0-1
  - 1.72.0.
  * Fri Jan 19 2007 Tomas Mraz <tmraz@redhat.com> 1.71.1-2
  - Add new wordml and especially highlighting (which is referenced
    from html) subdirs to Makefile.
  * Tue Jan 24 2006 Tim Waugh <twaugh@redhat.com> 1.69.1-5
  - Don't ship docsrc/* (bug #177256).
  - Don't ship the extensions (bug #177256).

* Sat Oct  8 2005 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.69.1-1vl1
- updated to 1.69.1 based on Fedora development

* Sun Dec 19 2004 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.67.2-2vl1
- updated to 1.67.2 based on Fedora development
  * Wed Dec  8 2004 Tim Waugh <twaugh@redhat.com> 1.67.2-2
  - Prevent expressions in passivetex output from index.xsl (bug #142229).
  * Thu Dec  2 2004 Tim Waugh <twaugh@redhat.com> 1.67.2-1
  - No longer need nbsp or listblock patches.

* Tue Jan 27 2004 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.64.1-2vl2
- patch from Fedora 1.64.1-6
  * Tue Jan 20 2004 Tim Waugh <twaugh@redhat.com> 1.64.1-6
  - Fix last margin-left fix (bug #113456).
  - Reduce instances of itemized/ordered lists having misalignments.
  * Sun Jan 18 2004 Tim Waugh <twaugh@redhat.com> 1.64.1-5
  - And another (bug #113456).
  * Thu Jan 15 2004 Tim Waugh <twaugh@redhat.com> 1.64.1-4
  - Fixed another instance of bug #113456 in lists layout.
  * Wed Jan 14 2004 Tim Waugh <twaugh@redhat.com> 1.64.1-3
  - Hard-code the margin-left work around to expect passivetex (bug #113456).

* Mon Jan  5 2004 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.64.1-2vl1
- based on Fedora 1.64.1-2
- fixed Japanese summary

* Sat May 24 2003 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.61.1-1vl1
- based on Redhat Rawhide 1.61.1-1
- add Japanese summary and description

* Tue Feb  4 2003 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.60.1-0vl1
- upstream release

* Tue Nov 26 2002 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.57.0-2vl1
- based on Redhat Rawhide 1.57.0-2

* Sat Oct 26 2002 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.57.0-0vl1
- 1.57.0

* Tue Sep 24 2002 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.55.0-0vl3
- Rebuilded for Vine Linux (add PreReq: docbook-dtd412-xml)
- based on rawhide 1.50.0 and source updated 1.55.0
- use better macros

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Thu May 23 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Wed May  1 2002 Tim Waugh <twaugh@redhat.com> 1.50.0-1
- 1.50.0.

* Thu Feb 21 2002 Tim Waugh <twaugh@redhat.com> 1.49-1
- 1.49.
- Rebuild in new environment.

* Fri Feb  1 2002 Tim Waugh <twaugh@redhat.com> 1.48-4
- Put URIs instead of pathnames in the XML catalog.

* Thu Jan 17 2002 Tim Waugh <twaugh@redhat.com> 1.48-3
- Back to /usr/share/sgml.

* Wed Jan 09 2002 Tim Powers <timp@redhat.com> 1.48-2
- automated rebuild

* Mon Jan  7 2002 Tim Waugh <twaugh@redhat.com> 1.48-1
- 1.48.

* Sat Dec  8 2001 Tim Waugh <twaugh@redhat.com> 1.47-2
- Conflict with PassiveTeX before 1.11.

* Tue Oct 16 2001 Tim Waugh <twaugh@redhat.com> 1.47-1
- 1.47-experimental.

* Tue Oct  9 2001 Tim Waugh <twaugh@redhat.com> 1.45-2
- Fix unversioned symlink.

* Mon Oct  8 2001 Tim Waugh <twaugh@redhat.com> 1.45-1
- XML Catalog entries.
- Move files to /usr/share/xml.

* Mon Oct  1 2001 Tim Waugh <twaugh@redhat.com> 1.45-0.1
- 1.45.
- Built for Red Hat Linux.

* Tue Jun 26 2001 Chris Runge <crunge@pobox.com>
- 1.40

* Sat Jun 09 2001 Chris Runge <crunge@pobox.com>
- added extensions and additional doc
- bin added to doc; the Perl files are for Win32 Perl and so need some
  conversion first

* Fri Jun 08 2001 Chris Runge <crunge@pobox.com>
- Initial RPM (based on docbook-style-dsssl RPM)
- note: no catalog right now (I don't know how to do it; and not sure why
  it is necessary)
