Summary: The Jack Audio Connection Kit
Name: jack-audio-connection-kit
Version: 1.9.10
Release: 2%{?_dist_release}
# The entire source (~500 files) is a mixture of these three licenses
License: GPLv2 and GPLv2+ and LGPLv2+
Group: System Environment/Daemons
URL: http://www.jackaudio.org

Vendor: Project Vine
Distribution: Vine Linux

#Source0: http://www.jackaudio.org/downloads/%{name}-%{version}.tar.gz
Source0: https://dl.dropbox.com/u/28869550/jack-%{version}.tar.bz2
Source1: %{name}-README.Fedora
Source2: %{name}-script.pa
Source3: %{name}-limits.conf

# No-date-footer hack to remove dates from doxygen documentation
Patch0:        jack-audio-connection-kit-no_date_footer.patch
# Build fix
Patch1:        jack-doxygen-output-dir-fix.patch
# We don't want the internal API documentation
Patch2:        jack-apidoc-only.patch
# Adjust default priority. RHBZ#795094
Patch3:        jack-realtime-compat.patch
# Enable renaming and reordering the jack ports RHBZ#887408
Patch4:        jack-portnames.patch
# Fix ppc64 mpd startup issue RHBZ#799552
Patch5:        jack-ppc64-long.patch
#Patch0:	jack-audio-connection-kit-0.124.1-freebob_driver.patch
# Fix building with gcc5
Patch6:        jack-gcc5.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: alsa-lib-devel
BuildRequires: celt-devel
BuildRequires: dbus-devel
BuildRequires: doxygen
BuildRequires: expat-devel
BuildRequires: libfreebob-devel >= 1.0.0
BuildRequires: libsamplerate-devel
BuildRequires: libsndfile-devel >= 1.0.0
BuildRequires: ncurses-devel
BuildRequires: pkgconfig
BuildRequires: python
BuildRequires: readline-devel
#BuildRequires: autoconf >= 2.59, automake >= 1.9.3, libtool
#BuildRequires: libdb-devel
#BuildRequires: libuuid-devel

%global groupname jackuser
%global pagroup   pulse-rt

Requires(pre): shadow-utils
Requires(post): /sbin/ldconfig

%description
JACK is a low-latency audio server, written primarily for the Linux
operating system. It can connect a number of different applications to
an audio device, as well as allowing them to share audio between
themselves. Its clients can run in their own processes (ie. as a
normal application), or can they can run within a JACK server (ie. a
"plugin").

JACK is different from other audio server efforts in that it has been
designed from the ground up to be suitable for professional audio
work. This means that it focuses on two key areas: synchronous
execution of all clients, and low latency operation.

%package dbus
Summary:	Jack D-Bus launcher
Group:		Applications/Multimedia
Requires: 	%{name} = %{version}-%{release}

%description dbus
Launcher to start Jack through D-Bus.


%package devel
Summary: 	Development files for %{name}
Summary(ja): 	%{name} の開発用ファイル
Group: 		Development/Libraries
Requires: 	%{name} = %{version}-%{release}
Requires: 	pkgconfig

%description devel
Development files for the Jack Audio Connection Kit.

%package example-clients
Summary: 	Example clients that use Jack 
Summary(ja): 	%{name} を利用したサンプルプログラム
Group: 		Applications/Multimedia
Requires: 	%{name} = %{version}-%{release}

%description example-clients
Small example clients that use the Jack Audio Connection Kit.

%prep
%setup -q -n jack-%{version}
%patch0 -p1 -b .nodate
%patch1 -p1 -b .outdir
%patch2 -p1 -b .nointernalapi
%patch3 -p1 -b .priority
%patch4 -p1 -b .portnames
%patch5 -p1 -b .mpd
%patch6 -p1 -b .gcc5

# Fix encoding issues
for file in ChangeLog README TODO; do
    sed 's|\r||' $file > $file.tmp
    iconv -f ISO-8859-1 -t UTF8 $file.tmp > $file.tmp2
    touch -r $file $file.tmp2
    mv -f $file.tmp2 $file
done

%build
export CPPFLAGS="$RPM_OPT_FLAGS -O0"
export PREFIX=%{_prefix}
# Parallel build disabled as it fails sometimes
./waf configure \
      %{?_smp_mflags} \
      --mandir=%{_mandir}/man1 \
      --libdir=%{_libdir} \
      --alsa \
      --classic \
      --clients 256 \
      --dbus \
      --doxygen \
      --freebob \
      --ports-per-application=2048

./waf build %{?_smp_mflags} -v

%install
rm -rf $RPM_BUILD_ROOT
./waf --destdir=$RPM_BUILD_ROOT install

# move doxygen documentation to the right place
mv $RPM_BUILD_ROOT%{_datadir}/jack-audio-connection-kit/reference .
rm -rf $RPM_BUILD_ROOT%{_datadir}/jack-audio-connection-kit

# install our limits to the /etc/security/limits.d
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/security/limits.d
sed -e 's,@groupname@,%groupname,g; s,@pagroup@,%pagroup,g;' \
    %{SOURCE3} > $RPM_BUILD_ROOT%{_sysconfdir}/security/limits.d/95-jack.conf

# prepare README.Fedora for documentation including
install -p -m644 %{SOURCE1} README.Fedora

# install pulseaudio script for jack (as documentation part)
install -p -m644 %{SOURCE2} jack.pa

# For compatibility with jack1
mv $RPM_BUILD_ROOT%{_bindir}/jack_rec $RPM_BUILD_ROOT%{_bindir}/jackrec

# Fix permissions of the modules
chmod 755 $RPM_BUILD_ROOT%{_libdir}/jack/*.so $RPM_BUILD_ROOT%{_libdir}/libjack*.so.*.*.*

%clean
rm -rf $RPM_BUILD_ROOT

%pre
getent group %groupname > /dev/null || groupadd -r %groupname
exit 0

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files 
%defattr(-,root,root)
%doc ChangeLog README README_NETJACK2 TODO
%doc README.Fedora
%doc jack.pa
%config(noreplace) %{_sysconfdir}/security/limits.d/*.conf
%{_bindir}/jackd
%{_bindir}/jackrec
%{_libdir}/jack/
%{_libdir}/libjack.so.*
%{_libdir}/libjacknet.so.*
%{_libdir}/libjackserver.so.*
%{_mandir}/man1/jackrec.1*
%{_mandir}/man1/jackd*.1*

%files dbus
%defattr(-,root,root)
%{_bindir}/jackdbus
%{_datadir}/dbus-1/services/org.jackaudio.service
%{_bindir}/jack_control

%files devel
%defattr(-,root,root)
%doc reference/html/
%{_includedir}/jack/
%{_libdir}/libjack.so
%{_libdir}/libjacknet.so
%{_libdir}/libjackserver.so
%{_libdir}/pkgconfig/jack.pc

%files example-clients
%defattr(-,root,root)
%{_bindir}/alsa_in
%{_bindir}/alsa_out
%{_bindir}/jack_alias
%{_bindir}/jack_bufsize
%{_bindir}/jack_connect
%{_bindir}/jack_disconnect
%{_bindir}/jack_cpu_load
%{_bindir}/jack_evmon
%{_bindir}/jack_freewheel
# These are not ready yet
#{_bindir}/jack_impulse_grabber
%exclude %{_mandir}/man1/jack_impulse_grabber.1*
%{_bindir}/jack_latent_client
%{_bindir}/jack_load
%{_bindir}/jack_unload
%{_bindir}/jack_lsp
%{_bindir}/jack_metro
%{_bindir}/jack_midi_dump
%{_bindir}/jack_midi_latency_test
%{_bindir}/jack_midiseq
%{_bindir}/jack_midisine
%{_bindir}/jack_monitor_client
%{_bindir}/jack_net_master
%{_bindir}/jack_net_slave
%{_bindir}/jack_netsource
%{_bindir}/jack_samplerate
%{_bindir}/jack_server_control
%{_bindir}/jack_session_notify
%{_bindir}/jack_showtime
%{_bindir}/jack_simple_client
%{_bindir}/jack_simple_session_client
%{_bindir}/jack_thru
%{_bindir}/jack_transport
%{_bindir}/jack_wait
%{_bindir}/jack_zombie
%{_mandir}/man1/alsa_*.1*
%{_mandir}/man1/jack_bufsize.1*
%{_mandir}/man1/jack_connect.1*
%{_mandir}/man1/jack_disconnect.1*
%{_mandir}/man1/jack_freewheel*.1*
%{_mandir}/man1/jack_load*.1*
%{_mandir}/man1/jack_unload*.1*
%{_mandir}/man1/jack_lsp.1*
%{_mandir}/man1/jack_metro.1*
%{_mandir}/man1/jack_monitor_client.1*
%{_mandir}/man1/jack_netsource.1*
%{_mandir}/man1/jack_samplerate.1*
%{_mandir}/man1/jack_showtime.1*
%{_mandir}/man1/jack_simple_client.1*
%{_mandir}/man1/jack_transport.1*
%{_mandir}/man1/jack_wait.1*

# tests
%{_bindir}/jack_cpu
%{_bindir}/jack_iodelay
%{_bindir}/jack_multiple_metro
%{_bindir}/jack_test
%{_mandir}/man1/jack_iodelay.1*


%changelog
* Sat Jul  2 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.9.10-2
- rebuilt with new toolchain.
- added Patch6 for gcc5.

* Thu Apr  2 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 1.9.10-1
- updated to 1.9.10
- built with readline 6.3
- added dbus subpackage

* Sun Jul 20 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.124.1
- update to 0.124.1
- add BuildRequires: libdb-devel, libuuid-devel
- add Patch0 (jack-audio-connection-kit-0.124.1-freebob_driver.patch)

* Wed Feb 22 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.121.3
- update to 0.121.3
- add BuildRequires: celt-devel

* Sun Sep 26 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.118.0-2
- rebuild with rpm-4.8.1 for pkg-config file
- add BuildRequires: libsamplerate-devel

* Fri May 21 2010 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 0.118.0-1
- new upstream release

* Sun Jul 12 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 0.116.1-1
- new upstream release
- rebuild with ncurses-devel

* Wed Jul 09 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 0.109.2-1
- initial build for Vine Linux

* Wed Feb 13 2008 Andy Shevchenko <andy@smile.org.ua> 0.109.2-1.1
- update to the last official release

* Mon Jan 21 2008 Andy Shevchenko <andy@smile.org.ua> 0.109.0-1
- update to the last official release (#429162)
- shut up the postinstall script (#359291)

* Sat Oct 20 2007 Andy Shevchenko <andy@smile.org.ua> 0.103.0-5
- fix timestamps to avoid multiarch conflicts (#341621)

* Tue Sep 04 2007 Andy Shevchenko <andy@smile.org.ua> 0.103.0-4
- fix Source Forge's URL scheme

* Thu Aug 16 2007 Andy Shevchenko <andy@smile.org.ua> 0.103.0-3
- fix according to new guidelines:
  - License tag
  - group creation

* Wed May 23 2007 Andy Shevchenko <andy@smile.org.ua> 0.103.0-1
- update to the last official release
- append defaults to the limits.conf (#221785, #235624)

* Wed Mar 07 2007 Andy Shevchenko <andy@smile.org.ua> 0.102.20-4
- drop libtermcap-devel build requirement (#231203)
- create special jackuser group (#221785)

* Sat Oct 28 2006 Andy Shevchenko <andy@smile.org.ua> 0.102.20-3
- fix BuildRequires: libfreebob -> libfreebob-devel

* Tue Oct 24 2006 Andy Shevchenko <andy@smile.org.ua> 0.102.20-2.1
- rebuild with libfreebob (should closed #211751)

* Wed Oct 11 2006 Andy Shevchenko <andy@smile.org.ua> 0.102.20-2.0
- update to 0.102.20
- drop patch0 (already in mainstream)
- no pack jack_transport (build error)
- pack new JACK MIDI files

* Tue Aug 29 2006 Andy Shevchenko <andriy@asplinux.com.ua> 0.101.1-13
- http://fedoraproject.org/wiki/Extras/Schedule/FC6MassRebuild

* Tue Aug 01 2006 Andy Shevchenko <andriy@asplinux.com.ua> 0.101.1-12
- use install instead of cp (#200835)

* Tue Jul 04 2006 Andy Shevchenko <andriy@asplinux.com.ua> 0.101.1-11
- update URL
- add BR: libtool

* Tue Jun 20 2006 Andy Shevchenko <andriy@asplinux.com.ua> 0.101.1-10
- add BRs: autoconf, automake
  (http://fedoraproject.org/wiki/QA/FixBuildRequires)

* Sat May 27 2006 Andy Shevchenko <andriy@asplinux.com.ua> 0.101.1-9
- remove --enable-stripped-jackd and --enable-optimize (use default flags)

* Fri May 19 2006 Andy Shevchenko <andriy@asplinux.com.ua> 0.101.1-8
- uniform directories items at %files section

* Wed May 17 2006 Andy Shevchenko <andriy@asplinux.com.ua> 0.101.1-7
- change License tag to GPL/LGPL
- remove --enable-shared (it should be default)
- add a -p flag to the line that copies README.Fedora

* Wed May 10 2006 Andy Shevchenko <andriy@asplinux.com.ua> 0.101.1-6
- apply clock fix for AMD X2 CPUs (please, refer to
  http://sourceforge.net/mailarchive/forum.php?thread_id=8085535&forum_id=3040)

* Wed May 03 2006 Andy Shevchenko <andriy@asplinux.com.ua> 0.101.1-5
- adjust spec after reviewing

* Thu Apr 27 2006 Andy Shevchenko <andriy@asplinux.com.ua> 0.101.1-4
- reformatting README.Fedora to 72 symbols width

* Wed Apr 26 2006 Andy Shevchenko <andriy@asplinux.com.ua> 0.101.1-3
- add README.Fedora
- remove useless BRs

* Mon Apr 24 2006 Andy Shevchenko <andriy@asplinux.com.ua> 0.101.1-2
- disable oss and portaudio engines
- use /dev/shm as jack tmpdir
- remove capabilities stuff

* Tue Apr 04 2006 Andy Shevchenko <andriy@asplinux.com.ua> 0.101.1-1
- update to 0.101.1

* Mon Mar 27 2006 Andy Shevchenko <andriy@asplinux.com.ua>
- update to 0.100.7 (#183912)
- adjust BR (add versions)
- replace files between examples and main packages
- own jack tmpdir

* Fri Mar 17 2006 Andy Shevchenko <andriy@asplinux.com.ua>
- no libs subpackage
- From Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>:
  - added configuration variable to build with/without capabilities
  - added --enable-optimize flag to configure script
  - disabled sse/mmx instructions in i386 build
  - create temporary directory as /var/lib/jack/tmp
  - create and erase tmp directory at install or uninstall
  - try to umount the temporary directory before uninstalling the package

* Fri Mar 03 2006 Andy Shevchenko <andriy@asplinux.com.ua>
- fix spec for extras injection

* Fri Nov 18 2005 Andy Shevchenko <andriy@asplinux.ru>
- exclude *.la files
- use dist tag

* Fri Oct 14 2005 Andy Shevchenko <andriy@asplinux.ru>
- 0.100.0
- no optimization

* Tue Sep 28 2004 Andy Shevchenko <andriy@asplinux.ru>
- 0.99.1

* Fri Aug 20 2004 Andy Shevchenko <andriy@asplinux.ru>
- rebuild from Mandrake
