%define build_compat32 %{?_with_compat32:1}%{!?_with_compat32:0}

# Build options:
# Components skipped by default:
%bcond_with doxygen

# Documentation install path
%global llvmdocdir() %{_docdir}/%1-%{version}

Name:           llvm
Version:        3.6.2
Release:        2%{?_dist_release}
Summary:        The Low Level Virtual Machine
Summary(ja):    LLVM - 低レベルバーチャルマシン

Group:          Development/Languages
License:        NCSA
URL:            http://llvm.org/
Source0:        http://llvm.org/releases/%{version}/llvm-%{version}.src.tar.xz
Source1:        http://llvm.org/releases/%{version}/cfe-%{version}.src.tar.xz
Source2:        http://llvm.org/releases/%{version}/compiler-rt-%{version}.src.tar.xz
Source3:        http://llvm.org/releases/%{version}/lldb-%{version}.src.tar.xz

# multilib fixes
Source10:        llvm-Config-config.h
Source11:        llvm-Config-llvm-config.h

# patches
Patch1:         llvm-3.5.0-build-fix.patch
Patch2:         0001-data-install-preserve-timestamps.patch

# newish glibc hides the definition of __extern_always_inline behind
# a check for gcc 4.3, clang pretends to be gcc 4.2.  a proper fix would
# be to build everything herein with gcc, but i don't have the patience
# atm, so in the interest of bootstrapping...
Patch100:       clang-fake-gcc43.patch
# http://llvm.org/bugs/show_bug.cgi?id=22625
Patch101:       clang-pr22625.patch

Patch200:       lldb-python.patch
Patch201:       lldb-fix-expression-parser.patch
Patch202:       lldb-python-module-symlink.patch

# Vine Patch
Patch1000: clang-3.6.1-driver-ld.gold.patch
Patch1001: clang-3.5.0-driver-lib64.patch
Patch1002: clang-3.5.0-driver-vine.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires:  binutils-devel
BuildRequires:  bison
BuildRequires:  chrpath
BuildRequires:  flex
BuildRequires:  gcc-c++ >= 3.4
BuildRequires:  groff
BuildRequires:  libffi-devel
BuildRequires:  libtool-ltdl-devel
BuildRequires:  libxml2-devel
BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-ctypes
BuildRequires:  ocaml-ounit
# for DejaGNU test suite
BuildRequires:  dejagnu tcl-devel python
%if %{with doxygen}
BuildRequires:  doxygen graphviz
%endif
# pod2man 
BuildRequires:  perl
# lldb
BuildRequires:  swig
BuildRequires:  libedit-devel
BuildRequires:  python-devel >= 2.7

Requires:       llvm-libs = %{version}-%{release}

# LLVM is not supported on PPC64
# http://llvm.org/bugs/show_bug.cgi?id=3729
ExcludeArch:    ppc64

%description
LLVM is a compiler infrastructure designed for compile-time,
link-time, runtime, and idle-time optimization of programs from
arbitrary programming languages.  The compiler infrastructure includes
mirror sets of programming tools as well as libraries with equivalent
functionality.


%package devel
Summary:        Libraries and header files for LLVM
Summary(ja):    LLVM のライブラリおよびヘッダファイル
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       libstdc++-devel
Requires:       libffi-devel
Provides:       llvm-static = %{version}-%{release}

%description devel
This package contains library and header files needed to develop new
native programs that use the LLVM infrastructure.


%package doc
Summary:        Documentation for LLVM
Summary(ja):    LLVM のドキュメント
Group:          Documentation
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}
# might seem redundant, but needed to kill off the old arch-ed -doc subpackage
Obsoletes:      %{name}-doc < %{version}-%{release}

%description doc
Documentation for the LLVM compiler infrastructure.


%package libs
Summary:        LLVM shared libraries
Summary(ja):    LLVM 共有ライブラリ
Group:          System Environment/Libraries

%description libs
Shared libraries for the LLVM compiler infrastructure.

%description libs -l ja
LLVM コンパイラ基盤の共有ライブラリです．

%package -n clang
Summary:        A C language family front-end for LLVM
Summary(ja):    LLVM の C 言語フロントエンド
License:        NCSA
Group:          Development/Languages
Requires:       %{name} = %{version}-%{release}
# clang requires gcc, clang++ requires libstdc++-devel
Requires:       libstdc++-devel
# remove clang-doc pacakge
Obsoletes:      clang-doc < %{version}-%{release}

%description -n clang
clang: noun
    1. A loud, resonant, metallic sound.
    2. The strident call of a crane or goose.
    3. C-language family front-end toolkit.

The goal of the Clang project is to create a new C, C++, Objective C
and Objective C++ front-end for the LLVM compiler. Its tools are built
as libraries and designed to be loosely-coupled and extensible.

%Package -n clang-libs
Summary:        Runtime library for clang
Summary(ja):    Clang のランタイムライブラリ
Group:          System Environment/Libraries

%description -n clang-libs
Runtime library for clang.

%description -n clang-libs -l ja
Clang のランタイムライブラリです．

%package -n clang-devel
Summary:        Header files for clang
Summary(ja):    Clang のヘッダファイル
Group:          Development/Libraries
Requires:       clang = %{version}-%{release}

%description -n clang-devel
This package contains header files for the Clang compiler.

%description -n clang-devel -l ja
Clang コンパイラのヘッダファイル集です．

%package -n clang-analyzer
Summary:        A source code analysis framework
Summary(ja):    ソースコー分析フレームワーク
License:        NCSA
Group:          Development/Languages
Requires:       clang = %{version}-%{release}
# not picked up automatically since files are currently not instaled
# in standard Python hierarchies yet
Requires:       python

%description -n clang-analyzer
The Clang Static Analyzer consists of both a source code analysis
framework and a standalone tool that finds bugs in C and Objective-C
programs. The standalone tool is invoked from the command-line, and is
intended to run in tandem with a build of a project or code base.

#%package -n clang-doc
#Summary:        Documentation for Clang
#Summary(ja):    Clang のドキュメント
#Group:          Documentation
#Requires:       %{name} = %{version}-%{release}
#
#%description -n clang-doc
#Documentation for the Clang compiler front-end.

%package -n lldb
Summary:        Next generation high-performance debugger
Summary(ja):    高性能デバッガー
License:        NCSA
Group:          Development/Debuggers
Requires:       %{name} = %{version}-%{release}

%description -n lldb
LLDB is a next generation, high-performance debugger. It is built as a set
of reusable components which highly leverage existing libraries in the
larger LLVM Project, such as the Clang expression parser and LLVM
disassembler.

%package -n lldb-devel
Summary:        Header files for LLDB
Summary(ja):    LLDB のヘッダファイル
Group:          Development/Libraries
Requires:       lldb = %{version}-%{release}

%description -n lldb-devel
This package contains header files for the LLDB debugger.


%if %{with doxygen}
%package apidoc
Summary:        API documentation for LLVM
Summary(ja):    LLVM の API ドキュメント
Group:          Documentation
BuildArch:      noarch
Requires:       %{name}-docs = %{version}-%{release}

%description apidoc
API documentation for the LLVM compiler infrastructure.

%package -n clang-apidoc
Summary:        API documentation for Clang
Summary(ja):    Clang の API ドキュメント
Group:          Documentation
BuildArch:      noarch

%description -n clang-apidoc
API documentation for the Clang compiler.
%endif

%package        ocaml
Summary:        OCaml binding for LLVM
Summary(ja):    LLVM の OCaml バインディング
Group:          System Environment/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml

%description    ocaml
OCaml binding for LLVM.

%package        ocaml-devel
Summary:        Development files for %{name}-ocaml
Summary(ja):    %{name}-ocaml の開発ファイル
Group:          Development/Libraries
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-ocaml = %{version}-%{release}
Requires:       ocaml

%description    ocaml-devel
The %{name}-ocaml-devel package contains libraries and signature files
for developing applications that use %{name}-ocaml.

%package ocaml-doc
Summary:        Documentation for %{name}-ocaml
Summary(ja):    %{name}-ocaml のドキュメント
Group:          Documentation
BuildArch:      noarch
Requires:       %{name}-ocaml = %{version}-%{release}
# might seem redundant, but needed to kill off the old arch-ed -doc subpackage
Obsoletes:      %{name}-ocaml-doc < %{version}-%{release}

%description ocaml-doc
HTML documentation for LLVM's OCaml binding.

# compat32'
%package -n compat32-%{name}-libs
Summary:        LLVM shared libraries
Summary(ja):    LLVM 共有ライブラリ
Group:          System Environment/Libraries
Requires: 	%{name}-libs = %{version}-%{release}

%description -n compat32-%{name}-libs
Shared libraries for the LLVM compiler infrastructure.


%prep
%setup -q -a1 -a2 -a3 -n llvm-%{version}.src 
rm -rf tools/clang tools/lldb projects/compiler-rt
mv cfe-%{version}.src tools/clang
mv compiler-rt-%{version}.src projects/compiler-rt
mv lldb-%{version}.src tools/lldb

#patch1 -p1
%patch2 -p1

# clang
#pushd tools/clang
#%patch100 -p1
#%patch101 -p0
#popd

# lldb
pushd tools/lldb
# careful when recreating this patch...
%patch200 -p1 -b .python
#patch201 -p2
%patch202 -p1
sed -i s/@lib@/%{_lib}/g scripts/Python/modules/readline/Makefile
popd

# Vine Linux
%patch1000 -p1 -b .driver-ld.gold
#%ifarch x86_64
#%patch1001 -p1 -b .driver-lib64
#%endif
%patch1002 -p1 -b .driver-vine

# fix library paths
sed -i 's|/lib /usr/lib $lt_ld_extra|%{_libdir} $lt_ld_extra|' configure
sed -i 's|(PROJ_prefix)/lib|(PROJ_prefix)/%{_lib}/%{name}|g' Makefile.config.in
sed -i 's|/lib\>|/%{_lib}/%{name}|g' tools/llvm-config/llvm-config.cpp

%build
# -fno-devirtualize shouldn't be necessary, but gcc has scary template-related
# bugs that make it so.  gcc 5 ought to be fixed.
export CC=gcc
export CXX=g++
export CFLAGS="%{optflags} -DLLDB_DISABLE_PYTHON"
export CXXFLAGS="%{optflags} -DLLDB_DISABLE_PYTHON"
%configure \
  --with-extra-options="-fno-devirtualize" \
  --with-extra-ld-options=-Wl,-Bsymbolic \
  --libdir=%{_libdir}/%{name} \
  --disable-polly \
  --disable-libcpp \
  --enable-cxx11 \
  --enable-clang-arcmt \
  --enable-clang-static-analyzer \
  --enable-clang-rewriter \
  --enable-optimized \
  --disable-profiling \
  --disable-assertions \
  --disable-werror \
  --disable-expensive-checks \
  --enable-debug-runtime \
  --enable-keep-symbols \
  --enable-jit \
  --enable-docs \
%if %{with doxygen}
  --enable-doxygen \
%else
  --disable-doxygen \
%endif
  --enable-threads \
  --enable-pthreads \
  --enable-zlib \
  --enable-pic \
  --enable-shared \
  --disable-embed-stdcxx \
  --enable-timestamps \
  --enable-backtraces \
  --enable-targets=x86,powerpc,arm,aarch64,cpp,nvptx,systemz,r600 \
  --enable-bindings=ocaml \
  --enable-libffi \
  --enable-ltdl-install \
  \
%ifarch armv7hl armv7l
  --with-cpu=cortex-a8 \
  --with-tune=cortex-a8 \
  --with-arch=armv7-a \
  --with-float=hard \
  --with-fpu=vfpv3-d16 \
  --with-abi=aapcs-vfp \
  %endif
  \
  --with-binutils-include=%{_includedir} \
  --with-c-include-dirs=%{_includedir}:$(echo %{_prefix}/lib/gcc/%{_target_cpu}*/*/include) \
  --with-optimize-option=-O3

#  --datadir=%{_libdir}/%{name} \
#  --enable-experimental-targets=R600 \

make %{?_smp_mflags} REQUIRES_RTTI=1 VERBOSE=1

%install
rm -rf %{buildroot}

make install DESTDIR=%{buildroot} \
     PROJ_docsdir=/moredocs

# you have got to be kidding me
rm -f %{buildroot}%{_bindir}/{FileCheck,count,not,verify-uselistorder,obj2yaml,yaml2obj}

# multilib fixes
mv %{buildroot}%{_bindir}/llvm-config{,-%{__isa_bits}}

pushd %{buildroot}%{_includedir}/llvm/Config
mv config.h config-%{__isa_bits}.h
cp -p %{SOURCE10} config.h
mv llvm-config.h llvm-config-%{__isa_bits}.h
cp -p %{SOURCE11} llvm-config.h
popd

# Create ld.so.conf.d entry
mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
cat >> %{buildroot}%{_sysconfdir}/ld.so.conf.d/llvm-%{_arch}.conf << EOF
%{_libdir}/%{name}
EOF

# Static analyzer not installed by default:
# http://clang-analyzer.llvm.org/installation#OtherPlatforms
# scan-view
mkdir -p %{buildroot}%{_libexecdir}/clang-analyzer/
cp -pr tools/clang/tools/scan-view %{buildroot}%{_libexecdir}/clang-analyzer/

# scan-build
mkdir -p %{buildroot}%{_libexecdir}/clang-analyzer/scan-build
for file in c++-analyzer ccc-analyzer scan-build scanview.css sorttable.js; do
    cp -p tools/clang/tools/scan-build/$file \
       %{buildroot}%{_libexecdir}/clang-analyzer/scan-build/
done

# scan-build manual page
mkdir -p %{buildroot}%{_mandir}/man1
cp -p tools/clang/tools/scan-build/scan-build.1 %{buildroot}%{_mandir}/man1/

# scan-build requires clang in search path
ln -s ../../../bin/clang %{buildroot}%{_libexecdir}/clang-analyzer/scan-build/clang

# launchers in /bin
for f in scan-{build,view}; do
  ln -s %{_libexecdir}/clang-analyzer/$f/$f %{buildroot}%{_bindir}/$f
done

# Get rid of erroneously installed example files.
rm %{buildroot}%{_libdir}/%{name}/*LLVMHello.*

# remove executable bit from static libraries
find %{buildroot}%{_libdir} -name "*.a" -type f -print0 | xargs -0 chmod -x

# Install man page for LLDB
mkdir -p %{buildroot}%{_mandir}/man1
cp tools/lldb/docs/lldb.1 %{buildroot}%{_mandir}/man1/

# Install documentation documentation
find %{buildroot}/moredocs/ -name "*.tar.gz" -print0 | xargs -0 rm -rf
mkdir -p %{buildroot}%{_docdir}

# llvm-doc
mkdir -p %{buildroot}%{llvmdocdir %{name}-doc}
cp -ar examples %{buildroot}%{llvmdocdir %{name}-doc}/examples
find %{buildroot}%{llvmdocdir %{name}-doc} -name Makefile -o -name CMakeLists.txt -o -name LLVMBuild.txt -print0 | xargs -0 rm -f

# llvm-apidoc
%if %{with doxygen}
mv %{buildroot}/moredocs/html/doxygen %{buildroot}%{llvmdocdir %{name}-apidoc}
%endif

# llvm-ocaml-doc
#mv %{buildroot}/moredocs/ocamldoc/html %{buildroot}%{llvmdocdir %{name}-ocaml-doc}

# clang
mkdir -p %{buildroot}%{llvmdocdir clang}
for f in LICENSE.TXT NOTES.txt README.txt CODE_OWNERS.TXT; do
  cp tools/clang/$f %{buildroot}%{llvmdocdir clang}/
done

# clang-apidoc
%if %{with doxygen}
cp -ar tools/clang/docs/doxygen/html %{buildroot}%{llvmdocdir clang-apidoc}
%endif

# lldb
mkdir -p %{buildroot}%{llvmdocdir lldb}
cp tools/lldb/LICENSE.TXT %{buildroot}%{llvmdocdir lldb}/

# delete the rest of installed documentation (because it's bad)
rm -rf %{buildroot}/moredocs

# install CMake modules
mkdir -p %{buildroot}%{_datadir}/llvm/cmake/
cp -p cmake/modules/*.cmake %{buildroot}%{_datadir}/llvm/cmake/

# remove RPATHs
file %{buildroot}/%{_bindir}/* | awk -F: '$2~/ELF/{print $1}' | xargs -r chrpath -d
file %{buildroot}/%{_libdir}/%{name}/*.so | awk -F: '$2~/ELF/{print $1}' | xargs -r chrpath -d


%check
# the || : is wrong, i know, but the git snaps fail to make check due to
# broken makefiles in the doc dirs.
make check LIT_ARGS="-v -j4" | tee llvm-testlog.txt ||:
make -C tools/clang/test TESTARGS="-v -j4" | tee clang-testlog.txt ||:


%clean
rm -rf %{buildroot}


%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%post -n clang-libs -p /sbin/ldconfig
%postun -n clang-libs -p /sbin/ldconfig

%post -n lldb -p /sbin/ldconfig
%postun -n lldb -p /sbin/ldconfig


%posttrans devel
# link llvm-config to the platform-specific file;
# use ISA bits as priority so that 64-bit is preferred
# over 32-bit if both are installed
alternatives \
  --install \
  %{_bindir}/llvm-config \
  llvm-config \
  %{_bindir}/llvm-config-%{__isa_bits} \
  %{__isa_bits}

%postun devel
if [ $1 -eq 0 ]; then
  alternatives --remove llvm-config \
    %{_bindir}/llvm-config-%{__isa_bits}
fi
exit 0


%files
%defattr(-,root,root,-)
%doc CREDITS.TXT README.txt
%{_bindir}/bugpoint
%{_bindir}/llc
%{_bindir}/lli
%{_bindir}/lli-child-target
%exclude %{_bindir}/llvm-config-%{__isa_bits}
%{_bindir}/llvm*
%{_bindir}/macho-dump
%{_bindir}/opt
%dir %{_datadir}/llvm
%exclude %{_mandir}/man1/clang.1.*
%exclude %{_mandir}/man1/scan-build.1.*
%exclude %{_mandir}/man1/lldb.1.*
%doc %{_mandir}/man1/*.1.*

%files devel
%defattr(-,root,root,-)
#doc %{llvmdocdir %{name}-devel}/
%{_bindir}/llvm-config-%{__isa_bits}
%{_includedir}/%{name}
%{_includedir}/%{name}-c
%{_libdir}/%{name}/*.a
%{_datadir}/%{name}/cmake

%files libs
%defattr(-,root,root,-)
%doc LICENSE.TXT
%config(noreplace) %{_sysconfdir}/ld.so.conf.d/llvm-%{_arch}.conf
%dir %{_libdir}/%{name}
%exclude %{_libdir}/%{name}/libclang.so
%exclude %{_libdir}/%{name}/liblldb.so
%{_libdir}/%{name}/*.so

%files -n clang
%defattr(-,root,root,-)
%doc %{llvmdocdir clang}/
%{_bindir}/clang*
%{_bindir}/c-index-test
%{_prefix}/lib/clang
%doc %{_mandir}/man1/clang.1.*

%files -n clang-libs
%defattr(-,root,root,-)
%{_libdir}/%{name}/libclang.so

%files -n clang-devel
%defattr(-,root,root,-)
#doc %{llvmdocdir clang-devel}/
%{_includedir}/clang
%{_includedir}/clang-c

%files -n clang-analyzer
%defattr(-,root,root,-)
%{_bindir}/scan-build
%{_bindir}/scan-view
%{_libexecdir}/clang-analyzer
%{_mandir}/man1/scan-build.1.*

%files -n lldb
%defattr(-,root,root,-)
%doc %{llvmdocdir lldb}/
%{_bindir}/lldb
%{_bindir}/lldb-*
%{_libdir}/%{name}/liblldb.so
# XXX double check this
#{python_sitearch}/*
%doc %{_mandir}/man1/lldb.1.*

%files -n lldb-devel
%defattr(-,root,root,-)
%{_includedir}/lldb

%files doc
%defattr(-,root,root,-)
%doc %{llvmdocdir %{name}-doc}/

%files ocaml
%defattr(-,root,root,-)
%{_libdir}/ocaml/*.cma
%{_libdir}/ocaml/*.cmi
%{_libdir}/ocaml/*.so
%{_libdir}/ocaml/META.llvm*

%files ocaml-devel
%defattr(-,root,root,-)
%{_libdir}/ocaml/*.a
%{_libdir}/ocaml/*.cmx*
%{_libdir}/ocaml/*.mli

%files ocaml-doc
%defattr(-,root,root,-)
#doc %{llvmdocdir %{name}-ocaml-doc}/

%if 0%{?_with_doxygen}
%files apidoc
%defattr(-,root,root,-)
%doc %{llvmdocdir %{name}-apidoc}/

%files -n clang-apidoc
%defattr(-,root,root,-)
%doc %{llvmdocdir clang-apidoc}/
%endif

%if %{build_compat32}
%files -n compat32-%{name}-libs
%defattr(-,root,root)
%doc LICENSE.TXT
%config(noreplace) %{_sysconfdir}/ld.so.conf.d/llvm-%{_arch}.conf
%dir %{_libdir}/%{name}
%exclude %{_libdir}/%{name}/libclang.so
%exclude %{_libdir}/%{name}/liblldb.so
%{_libdir}/%{name}/*.so
%endif

%changelog
* Thu Jun 30 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.6.2-2
- rebuild with gcc-5.4.0

* Sat Sep  5 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 3.6.2-1
- new upstream release
- added BR: ocaml-ctypes

* Thu Jun  4 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 3.6.1-1
- new upstream release
- dropt Patch 1, 201 and 1001
- updated Patch 1000

* Tue Mar 24 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 3.5.1-1
- updated to 3.5.1
- added Patch1, 2, 100, 101, 200, 201 and 202 from Fedora 
- added clang-libs, lldb, lldb-devel and compat32-llvm-libs subpackage
- obsoleted clang-doc
- built with ocaml 4.02.1

* Sat Nov 29 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.5.0-2
- fix <BTS:2832>
  - fix configure option "--with-c-include-dirs"
  - update Patch1000: clang-3.5.0-driver-ld.gold.patch
  - update Patch1001: clang-3.5.0-driver-lib64.patch
  - update Patch1002: clang-3.5.0-driver-vine.patch

* Tue Oct 28 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.5.0-1
- update to 3.5.0
- remove Patch11 (clang-hardfloat-hack.patch)

* Sun Jul 06 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.3-2
- rebuild with libffi-3.0.13

* Mon Oct 28 2013 Daisuke SUZUKI <daisuke@linux.or.jp> 3.3-1
- update to 3.3

* Mon Dec 03 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.1-2
- ld.gold (patch1000,1001)
- add /%{_lib} to ld search path
- add support *-vine-linux gcc (patch1002)

* Fri Nov 30 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 3.1-1
- update to 3.1

* Tue Jan 24 2012 NAKAMURA Kenta <kenta@vinelinux.org> - 3.0-1
- updated to 3.0 release

* Sun Jan 15 2012 NAKAMURA Kenta <kenta@vinelinux.org> - 2.9-3
- added patch 2-4 to support -O4 link-time optimization

* Fri Sep  9 2011 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.9-2
- disable -fno-var-tracking-assignments on ppc
  (seems like gcc-4.4.5 still doesn't support this)

* Thu Aug 25 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.9-1
- new upstream release
- add BR: libffi-devel
- add R: libffi-devel to -devel

* Sun May 23 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.7-1
- initial build for Vine Linux

* Sun May  2 2010 Michel Salim <salimma@fedoraproject.org> - 2.7-1
- Update to final 2.7 release

* Sun Mar 28 2010 Michel Salim <salimma@fedoraproject.org> - 2.7-0.1.pre1
- Update to first 2.7 pre-release

* Fri Sep 18 2009 Michel Salim <salimma@fedoraproject.org> - 2.6-0.6.pre2
- Update to 2.6 pre-release2
- -devel subpackage now virtually provides -static

* Wed Sep  9 2009 Michel Salim <salimma@fedoraproject.org> - 2.6-0.5.pre1
- Disable var tracking assignments on PPC

* Wed Sep  9 2009 Michel Salim <salimma@fedoraproject.org> - 2.6-0.4.pre1
- Don't adjust clang include dir; files there are noarch (bz#521893)
- Enable clang unit tests
- clang and clang-analyzer renamed; no longer depend on llvm at runtime

* Mon Sep  7 2009 Michel Salim <salimma@fedoraproject.org> - 2.6-0.3.pre1
- Package Clang's static analyzer tools

* Mon Sep  7 2009 Michel Salim <salimma@fedoraproject.org> - 2.6-0.2.pre1
- PIC is now enabled by default; explicitly disable on %%{ix86}

* Mon Sep  7 2009 Michel Salim <salimma@fedoraproject.org> - 2.6-0.1.pre1
- First 2.6 prerelease
- Enable Clang front-end
- Enable debuginfo generation

* Sat Sep  5 2009 Michel Salim <salimma@fedoraproject.org> - 2.5-6
- Disable assertions (needed by OpenGTL, bz#521261)
- Align spec file with upstream build instructions
- Enable unit tests

* Sat Aug 22 2009 Michel Salim <salimma@fedoraproject.org> - 2.5-5
- Only disable PIC on %%ix86; ppc actually needs it

* Sat Aug 22 2009 Michel Salim <salimma@fedoraproject.org> - 2.5-4
- Disable use of position-independent code on 32-bit platforms
  (buggy in LLVM <= 2.5)

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Mar  4 2009 Michel Salim <salimma@fedoraproject.org> - 2.5-2
- Remove build scripts; they require the build directory to work

* Wed Mar  4 2009 Michel Salim <salimma@fedoraproject.org> - 2.5-1
- Update to 2.5
- Package build scripts (bug #457881)

* Tue Dec  2 2008 Michel Salim <salimma@fedoraproject.org> - 2.4-2
- Patched build process for the OCaml binding

* Tue Dec  2 2008 Michel Salim <salimma@fedoraproject.org> - 2.4-1
- Update to 2.4
- Package Ocaml binding

* Wed Jun 18 2008 Bryan O'Sullivan <bos@serpentine.com> - 2.3-2
- Add dependency on groff

* Wed Jun 18 2008 Bryan O'Sullivan <bos@serpentine.com> - 2.3-1
- LLVM 2.3

* Thu May 29 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.2-4
- fix license tags

* Wed Mar  5 2008 Bryan O'Sullivan <bos@serpentine.com> - 2.2-3
- Fix compilation problems with gcc 4.3

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 2.2-2
- Autorebuild for GCC 4.3

* Sun Jan 20 2008 Bryan O'Sullivan <bos@serpentine.com> - 2.1-2
- Fix review comments

* Sun Jan 20 2008 Bryan O'Sullivan <bos@serpentine.com> - 2.1-1
- Initial version
